Changelog
=========

0.3 (2015-05-28)
----------------

- Remove duplicated URLs from final report
  [keul] 
- Do not include same version of an URL with anchors
  [keul]
- Inspect also resources from CSS (backgroun images, fonts, ...)
  [keul]
- Script was not properly working outside homepage if a "base" tag
  was not provided
  [keul]

0.2 (2014-04-02)
----------------

- Added support for ``src`` attribute of ``iframe`` tag
  [keul]
- Added support for ``src`` attribute of ``source`` tag
  (HTML 5 video element)
  [keul]
- Do not break if ``base`` tag is not present
  [keul]

0.1 (2013-01-30)
----------------

- initial release